"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextMapDeploymentDocumenterMojo = void 0;
var resource_service_1 = require("./application/resource.service");
var mojo_parameters_1 = require("./infrastructure/mojo-parameters");
var context_map_server_client_1 = require("./infrastructure/client/context-map-server.client");
var ContextMapDeploymentDocumenterMojo = /** @class */ (function () {
    function ContextMapDeploymentDocumenterMojo(parameters) {
        this.parameters = parameters;
    }
    ContextMapDeploymentDocumenterMojo.prototype.execute = function () {
        var mojoParameters = this.createMojoParameters();
        console.log("Documenting deployment of " + this.parameters.version + " to " + this.parameters.environment);
        this.documentDeployment(mojoParameters, this.parameters.version, this.parameters.environment);
        console.log('Finished documenting deployment.');
    };
    ContextMapDeploymentDocumenterMojo.prototype.createMojoParameters = function () {
        var resourceService = new resource_service_1.ResourceService();
        var config = resourceService.scanConfiguration();
        if (this.parameters.key == null) {
            this.parameters.key = config.getKey();
        }
        if (this.parameters.host == null) {
            this.parameters.host = config.getHost();
        }
        if (this.parameters.componentName == null) {
            this.parameters.componentName = config.getName();
        }
        var mojoParameters = new mojo_parameters_1.MojoParameters();
        mojoParameters.setKey(this.parameters.key);
        mojoParameters.componentName = this.parameters.componentName;
        mojoParameters.customHost = this.parameters.host;
        return mojoParameters;
    };
    ContextMapDeploymentDocumenterMojo.prototype.documentDeployment = function (mojoParameters, version, environment) {
        var client = new context_map_server_client_1.ContextMapServerClient(mojoParameters);
        var deployment = this.createDeployment(mojoParameters, version, environment);
        client.documentDeployment(deployment);
    };
    ContextMapDeploymentDocumenterMojo.prototype.createDeployment = function (mojoParameters, version, environment) {
        var deployment = {
            componentName: mojoParameters.componentName,
            version: version,
            environment: environment
        };
        return deployment;
    };
    return ContextMapDeploymentDocumenterMojo;
}());
exports.ContextMapDeploymentDocumenterMojo = ContextMapDeploymentDocumenterMojo;
