"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextMapServerClient = void 0;
var http_service_1 = require("./http.service");
var ContextMapServerClient = /** @class */ (function () {
    function ContextMapServerClient(parameters) {
        this.parameters = parameters;
        this.httpService = new http_service_1.HttpService(parameters);
        this.signinResponse = this.signIn();
    }
    ContextMapServerClient.prototype.processScan = function (scan) {
        return this.sendScan(scan, this.signinResponse);
    };
    ContextMapServerClient.prototype.addRelease = function (releaseDetail) {
        this.httpService.post("/scans/releases", releaseDetail, "Bearer " + this.signinResponse.jwt, false);
    };
    ContextMapServerClient.prototype.addDecisionRecord = function (adrDetail) {
        this.httpService.post("/scans/decision-records", adrDetail, "Bearer " + this.signinResponse.jwt, false);
    };
    ContextMapServerClient.prototype.setDecisionRecordForOverview = function (adrDetail) {
        this.httpService.post("/scans/decision-records/for-overview", adrDetail, "Bearer " + this.signinResponse.jwt, false);
    };
    ContextMapServerClient.prototype.addFeatureFile = function (ffDetail) {
        this.httpService.post("/scans/feature-files", ffDetail, "Bearer " + this.signinResponse.jwt, false);
    };
    ContextMapServerClient.prototype.documentDeployment = function (deployment) {
        this.httpService.post("/scans/deployments", deployment, "Bearer " + this.signinResponse.jwt, false);
    };
    ContextMapServerClient.prototype.getReleaseNames = function (componentName) {
        try {
            return this.httpService.get('/components/release-names?componentName=' + componentName, "Bearer " + this.signinResponse.jwt);
        }
        catch (error) {
            console.log('Unable to get previous releases');
            return [];
        }
    };
    ContextMapServerClient.prototype.signIn = function () {
        console.log("Authenticating");
        var request = {
            username: this.parameters.getUsername(),
            password: this.parameters.getPassword()
        };
        var resp = { jwt: "" };
        resp = this.httpService.post("/api/auth/signin", request);
        return resp;
    };
    ContextMapServerClient.prototype.sendScan = function (scan, signinResponse) {
        console.log("Sending scan");
        var resp = this.httpService.post("/scans", scan, "Bearer " + signinResponse.jwt);
        return resp;
    };
    return ContextMapServerClient;
}());
exports.ContextMapServerClient = ContextMapServerClient;
