"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpService = void 0;
var async_call_blocker_1 = require("../async-call-blocker");
// const http = require("http");
// const https = require("https");
var axios = require('axios');
var HttpService = /** @class */ (function () {
    function HttpService(parameters) {
        this.parameters = parameters;
        if (this.parameters.customHost != null && this.parameters.customHost.length > 0) {
            console.info("*** Using custom host ***");
            this.host = this.parameters.customHost;
        }
        else {
            this.host = 'https://contextmap-server.azurewebsites.net';
        }
    }
    HttpService.prototype.get = function (path, authHeader) {
        if (authHeader === void 0) { authHeader = null; }
        var ready = false;
        var responseBody = null;
        var config = {
            headers: {
                "Content-Type": "application/json",
                Authorization: authHeader
            }
        };
        var url = this.host + path;
        axios.get(url, config)
            .then(function (response) {
            if (response.status >= 200 && response.status <= 299) {
                responseBody = response.data;
            }
            else {
                console.error("Error: " + response.data);
            }
            ready = true;
        })
            .catch(function (error) {
            console.error("Error: " + error);
            ready = true;
        });
        // Block until response received
        while (!ready) {
            (0, async_call_blocker_1.blockExecution)();
        }
        return responseBody;
    };
    HttpService.prototype.post = function (path, requestBody, authHeader, expectResponseBody) {
        if (authHeader === void 0) { authHeader = null; }
        if (expectResponseBody === void 0) { expectResponseBody = true; }
        var ready = false;
        var responseBody = null;
        var config = {
            headers: {
                "Content-Type": "application/json",
                Authorization: authHeader
            }
        };
        var url = this.host + path;
        axios.post(url, requestBody, config)
            .then(function (response) {
            if (response.status >= 200 && response.status <= 299) {
                if (expectResponseBody) {
                    responseBody = response.data;
                }
            }
            else {
                console.error("Error: " + response.data);
            }
            ready = true;
        })
            .catch(function (error) {
            console.error("Error: " + error);
            ready = true;
        });
        // Block until response received
        while (!ready) {
            (0, async_call_blocker_1.blockExecution)();
        }
        return responseBody;
    };
    return HttpService;
}());
exports.HttpService = HttpService;
